package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.ZyArticle;

/**
 * 中业文章管理Service接口
 * 
 * @author libao
 * @date 2024-05-24
 */
public interface IZyArticleService 
{
    /**
     * 查询中业文章管理
     * 
     * @param id 中业文章管理主键
     * @return 中业文章管理
     */
    public ZyArticle selectZyArticleById(Long id);

    /**
     * 查询中业文章管理列表
     * 
     * @param zyArticle 中业文章管理
     * @return 中业文章管理集合
     */
    public List<ZyArticle> selectZyArticleList(ZyArticle zyArticle);

    /**
     * 新增中业文章管理
     * 
     * @param zyArticle 中业文章管理
     * @return 结果
     */
    public int insertZyArticle(ZyArticle zyArticle);

    /**
     * 修改中业文章管理
     * 
     * @param zyArticle 中业文章管理
     * @return 结果
     */
    public int updateZyArticle(ZyArticle zyArticle);

    /**
     * 批量删除中业文章管理
     * 
     * @param ids 需要删除的中业文章管理主键集合
     * @return 结果
     */
    public int deleteZyArticleByIds(Long[] ids);

    /**
     * 删除中业文章管理信息
     * 
     * @param id 中业文章管理主键
     * @return 结果
     */
    public int deleteZyArticleById(Long id);
}
