package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.ZyArticle;
import com.ruoyi.system.service.IZyArticleService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 中业文章管理Controller
 * 
 * @author libao
 * @date 2024-05-24
 */
@RestController
@RequestMapping("/system/article")
public class ZyArticleController extends BaseController
{
    @Autowired
    private IZyArticleService zyArticleService;

    /**
     * 查询中业文章管理列表
     */
    @PreAuthorize("@ss.hasPermi('system:article:list')")
    @GetMapping("/list")
    public TableDataInfo list(ZyArticle zyArticle)
    {
        startPage();
        List<ZyArticle> list = zyArticleService.selectZyArticleList(zyArticle);
        return getDataTable(list);
    }

    /**
     * 导出中业文章管理列表
     */
    @PreAuthorize("@ss.hasPermi('system:article:export')")
    @Log(title = "中业文章管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ZyArticle zyArticle)
    {
        List<ZyArticle> list = zyArticleService.selectZyArticleList(zyArticle);
        ExcelUtil<ZyArticle> util = new ExcelUtil<ZyArticle>(ZyArticle.class);
        util.exportExcel(response, list, "中业文章管理数据");
    }

    /**
     * 获取中业文章管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:article:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(zyArticleService.selectZyArticleById(id));
    }

    /**
     * 新增中业文章管理
     */
    @PreAuthorize("@ss.hasPermi('system:article:add')")
    @Log(title = "中业文章管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ZyArticle zyArticle)
    {
        return toAjax(zyArticleService.insertZyArticle(zyArticle));
    }

    /**
     * 修改中业文章管理
     */
    @PreAuthorize("@ss.hasPermi('system:article:edit')")
    @Log(title = "中业文章管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ZyArticle zyArticle)
    {
        return toAjax(zyArticleService.updateZyArticle(zyArticle));
    }

    /**
     * 删除中业文章管理
     */
    @PreAuthorize("@ss.hasPermi('system:article:remove')")
    @Log(title = "中业文章管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(zyArticleService.deleteZyArticleByIds(ids));
    }
}
